==> MeatAxe-2.4.1.tar.gz: mtx/2.4/src/bswrite.c <==
/* ============================= C MeatAxe ==================================
   File:        $Id: bswrite.c,v 1.1.1.1 2000/01/07 16:42:26 mringe Exp $
   Comment:     Write a bit string to a file.
   --------------------------------------------------------------------------
   (C) Copyright 1998 Michael Ringe, Lehrstuhl D fuer Mathematik,
   RWTH Aachen, Germany  <mringe@math.rwth-aachen.de>
   This program is free software; see the file COPYING for details.
   ========================================================================== */

#include "meataxe.h"

   
/* --------------------------------------------------------------------------
   Local data
   -------------------------------------------------------------------------- */

MTX_DEFINE_FILE_INFO



/*{{{ --------------------------------------------------------------------------
!section obj.bs
!function BsWrite "Write a bit string to a file"
!arg bs
    Pointer to the bit string.
!arg f
    File to write to.
!return
    $0$ on success, $-1$ on error.
!description
    This function writes a bit string to a file at the current file
    pointer position.
!seealso
-------------------------------------------------------------------------- }}}*/

int BsWrite(BitString_t *bs, FILE *f)

{
    long hdr[3];	    /* File header */


    /* Check arguments 
       --------------- */
    if (!BsIsValid(bs))
    {
	MTX_ERROR1("bs: %E",MTX_ERR_BADARG);
	return -1;
    }
    if (f == NULL)
    {
	MTX_ERROR1("f: %E",MTX_ERR_BADARG);
	return -1;
    }

    /* Write header
       ------------ */
    hdr[0] = -3;
    hdr[1] = bs->Size;
    hdr[2] = 0;
    if (SysWriteLong(f,hdr,3) != 3)
    {
	MTX_ERROR("Cannot write bit string header");
	return -1;
    }

    /* Write data
       ---------- */
    if (SysWriteLong(f,(const long *)bs->Data,bs->BufSize) != bs->BufSize)
    {
	MTX_ERROR("Cannot write bit string data");
	return -1;
    }

    return 0;
}

==> MeatAxe-2.4.8.tar.gz: mtx/2.4/src/bswrite.c <==
/* ============================= C MeatAxe ==================================
   File:        $Id: bswrite.c,v 1.1.1.1 2000/01/07 16:42:26 mringe Exp $
   Comment:     Write a bit string to a file.
   --------------------------------------------------------------------------
   (C) Copyright 1998 Michael Ringe, Lehrstuhl D fuer Mathematik,
   RWTH Aachen, Germany  <mringe@math.rwth-aachen.de>
   This program is free software; see the file COPYING for details.
   ========================================================================== */

#include "meataxe.h"

   
/* --------------------------------------------------------------------------
   Local data
   -------------------------------------------------------------------------- */

MTX_DEFINE_FILE_INFO



/*------------------------------------------------------------------------------
@! Write a bit string to a file.
@  This function writes a bit string to a file at the current file
   pointer position.
@@ obj.bs
------------------------------------------------------------------------------*/

int BsWrite(
    BitString_t *bs,	/*@ Pointer to the bit string.*/
    FILE *f		/*@ File to write to.*/
    )			/*@ 0 on success, -1 on error.*/
{
    long hdr[3];	/* File header */

    /* Check arguments 
       --------------- */
    if (!BsIsValid(bs))
    {
	MTX_ERROR1("bs: %E",MTX_ERR_BADARG);
	return -1;
    }
    if (f == NULL)
    {
	MTX_ERROR1("f: %E",MTX_ERR_BADARG);
	return -1;
    }

    /* Write header
       ------------ */
    hdr[0] = -3;
    hdr[1] = bs->Size;
    hdr[2] = 0;
    if (SysWriteLong32(f,hdr,3) != 3)
    {
	MTX_ERROR("Cannot write bit string header");
	return -1;
    }

    /* Write data
       ---------- */
    if (SysWriteLongX(f,bs->Data,(bs->Size + 7) / 8) != (bs->Size + 7) / 8)
    {
	MTX_ERROR("Cannot write bit string data");
	return -1;
    }

    return 0;
}
